abjadbooktools.CodeBlock
========================

.. abjad-lineage:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock

.. autoclass:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.ending_line_number
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.hide
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.lines
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.processed_results
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.starting_line_number
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.storage_format
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.strip_prompt
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.read
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__le__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__repr__
   :noindex:
